@@ -680,6 +680,7 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["log", "raise"] = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
+        warn_when_scanning: bool = True,
     ) -> Iterator[tuple[Series, SeriesJsonLinesOffset]]:
         ...
 
@@ -692,6 +693,7 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["yield"],
         series_codes: Optional[Iterable[SeriesCode]] = None,
+        warn_when_scanning: bool = True,
     ) -> Iterator[Union[tuple[Series, SeriesJsonLinesOffset], DBnomicsDataModelError]]:
         ...
 
@@ -703,6 +705,7 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: OnError = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
+        warn_when_scanning: bool = True,
     ) -> Union[
         Iterator[tuple[Series, SeriesJsonLinesOffset]],
         Iterator[Union[tuple[Series, SeriesJsonLinesOffset], DBnomicsDataModelError]],
@@ -717,6 +720,7 @@ class FileSystemStorage(Storage):
                 include_observations=include_observations,
                 on_error=on_error,
                 series_codes=series_codes,
+                warn_when_scanning=warn_when_scanning,
             )
         ):
             if isinstance(data_or_exc, DBnomicsDataModelError):
@@ -750,6 +754,7 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["log", "raise"] = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
+        warn_when_scanning: bool = True,
     ) -> Iterator[tuple[dict, SeriesJsonLinesOffset]]:
         ...
 
@@ -761,6 +766,7 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["yield"],
         series_codes: Optional[Iterable[SeriesCode]] = None,
+        warn_when_scanning: bool = True,
     ) -> Iterator[Union[Iterator[tuple[dict, SeriesJsonLinesOffset]], DBnomicsDataModelError]]:
         ...
 
@@ -771,6 +777,7 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: OnError = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
+        warn_when_scanning: bool = True,
     ) -> Union[
         Iterator[tuple[dict, SeriesJsonLinesOffset]],
         Iterator[Union[Iterator[tuple[dict, SeriesJsonLinesOffset]], DBnomicsDataModelError]],
@@ -795,12 +802,13 @@ class FileSystemStorage(Storage):
             )
 
         if remaining_series_codes is None or remaining_series_codes:
-            logger.warning(
-                "%s of the dataset %r are about to be loaded by scanning its JSON Lines file, "
-                "this is a performance bottleneck",
-                "All the series" if remaining_series_codes is None else f"{len(remaining_series_codes)} series",
-                dataset_code,
-            )
+            if warn_when_scanning:
+                logger.warning(
+                    "%s of the dataset %r are about to be loaded by scanning its JSON Lines file, "
+                    "this is a performance bottleneck",
+                    "All the series" if remaining_series_codes is None else f"{len(remaining_series_codes)} series",
+                    dataset_code,
+                )
             yield from self._iter_series_jsonl_by_scanning(
                 series_jsonl_path,
                 remaining_series_codes,
